@@ -52,21 +52,51 @@ from ubuntu_sso.credentials import (
 )
 from ubuntu_sso.keyring import get_token_name, Keyring
 from ubuntu_sso.logger import setup_logging, log_call
+from ubuntu_sso.utils import compat
 
 
 logger = setup_logging("ubuntu_sso.main")
 TIMEOUT_INTERVAL = 10000  # 10 seconds
 
-# pylint: disable=C0103, W0703
+# pylint: disable=C0103, W0703, W0621
 
 if sys.platform == 'win32':
-    from ubuntu_sso.main import windows
-    source = windows
-    TIMEOUT_INTERVAL = 10000000000  # forever (hack)
-else:
-    from ubuntu_sso.main import linux
-    source = linux
+    from ubuntu_sso.main import windows as source
+    from ubuntu_sso.main.perspective_broker import (
+        finish_setup,
+        main as main_func,
+        timeout_func,
+        shutdown_func,
+        start_setup,
+        )
 
+    source.finish_setup = finish_setup
+    source.timeout_func = timeout_func
+    source.shutdown_func = shutdown_func
+    source.start_setup = start_setup
+    source.main = main_func
+
+    TIMEOUT_INTERVAL = 10000000000  # forever (hack)
+elif sys.platform == 'darwin':
+    from ubuntu_sso.main import darwin as source
+    from ubuntu_sso.main.perspective_broker import (
+        finish_setup,
+        main as main_func,
+        timeout_func,
+        shutdown_func,
+        start_setup,
+        )
+
+    source.finish_setup = finish_setup
+    source.timeout_func = timeout_func
+    source.shutdown_func = shutdown_func
+    source.start_setup = start_setup
+    source.main = main_func
+else:
+    from ubuntu_sso.main import linux as source
+
+
+UbuntuSSOClient = source.UbuntuSSOClient
 UbuntuSSOProxy = source.UbuntuSSOProxy
 get_sso_client = source.get_sso_client
 
@@ -80,7 +110,7 @@ def except_to_errdict(e):
         result["message"] = e.__class__.__doc__
     elif isinstance(e.args[0], dict):
         result.update(e.args[0])
-    elif isinstance(e.args[0], basestring):
+    elif isinstance(e.args[0], compat.basestring):
         result["message"] = e.args[0]
 
     return result
@@ -317,7 +347,7 @@ class CredentialsManagement(object):
 
     def _parse_args(self, args):
         """Retrieve values from the generic param 'args'."""
-        result = dict(i for i in args.iteritems() if i[0] in self.valid_keys)
+        result = dict(i for i in args.items() if i[0] in self.valid_keys)
         result[WINDOW_ID_KEY] = int(args.get(WINDOW_ID_KEY, 0))
         return result
 
