@@ -28,6 +28,8 @@
 # files in the program, then also delete it here.
 """Tests for the main SSO client code."""
 
+from __future__ import unicode_literals
+
 import logging
 
 from functools import partial
@@ -137,7 +139,7 @@ class ExceptToErrdictTestCase(TestCase):
         class MyException(Exception):
             """Custom Exception."""
 
-        message = u'My custom error for ♥ Ubuntu'
+        message = 'My custom error for ♥ Ubuntu'
         my_exc = MyException(message)
         result = except_to_errdict(my_exc)
         self.assertEqual(result["errtype"], my_exc.__class__.__name__)
@@ -145,7 +147,7 @@ class ExceptToErrdictTestCase(TestCase):
 
     def test_first_arg_is_unicode(self):
         """If the first arg is a unicode, use it as the message."""
-        sample_string = u"a sample string"
+        sample_string = "a sample string"
         e = TestExceptToErrdictException(sample_string)
         result = except_to_errdict(e)
         self.assertEqual(result["errtype"], e.__class__.__name__)
@@ -160,7 +162,7 @@ class ExceptToErrdictTestCase(TestCase):
 
     def test_some_other_thing_as_first_arg(self):
         """If first arg is not basestring nor dict, then repr all args."""
-        sample_args = (None, u"unicode2\ufffd", "errorcode3")
+        sample_args = (None, "unicode2\ufffd", "errorcode3")
         e = TestExceptToErrdictException(*sample_args)
         result = except_to_errdict(e)
         self.assertEqual(result["errtype"], e.__class__.__name__)
