@@ -37,8 +37,10 @@ from ubuntu_sso.logger import setup_gui_logging
 from ubuntu_sso.qt import LINK_STYLE, build_general_error_message
 from ubuntu_sso.qt.sso_wizard_page import SSOWizardPage
 from ubuntu_sso.qt.ui.current_user_sign_in_ui import Ui_CurrentUserSignInPage
+from ubuntu_sso.utils import compat
 from ubuntu_sso.utils.ui import (
     CANCEL_BUTTON,
+    CREATE_ACCOUNT_LABEL,
     EMAIL_LABEL,
     FORGOTTEN_PASSWORD_BUTTON,
     is_correct_email,
@@ -56,9 +58,10 @@ class CurrentUserSignInPage(SSOWizardPage):
     """Wizard Page that lets a current user Sign into Ubuntu Single Sign On."""
 
     ui_class = Ui_CurrentUserSignInPage
-    userLoggedIn = QtCore.pyqtSignal(unicode)
+    userLoggedIn = QtCore.pyqtSignal(compat.text_type)
     passwordForgotten = QtCore.pyqtSignal()
-    userNotValidated = QtCore.pyqtSignal(unicode)
+    createAccount = QtCore.pyqtSignal()
+    userNotValidated = QtCore.pyqtSignal(compat.text_type)
 
     @property
     def _signals(self):
@@ -76,12 +79,12 @@ class CurrentUserSignInPage(SSOWizardPage):
     @property
     def password(self):
         """Return the content of the password edit."""
-        return unicode(self.ui.password_edit.text())
+        return compat.text_type(self.ui.password_edit.text())
 
     def on_user_not_validated(self, app_name, email):
         """Show the validate email page."""
         self.hide_overlay()
-        email = unicode(self.ui.email_edit.text())
+        email = compat.text_type(self.ui.email_edit.text())
         self.userNotValidated.emit(email)
 
     # Invalid names of Qt-inherited methods
@@ -117,29 +120,36 @@ class CurrentUserSignInPage(SSOWizardPage):
         forgotten_text = LINK_STYLE.format(link_url='#',
                             link_text=FORGOTTEN_PASSWORD_BUTTON)
         self.ui.forgot_password_label.setText(forgotten_text)
+        link_text = CREATE_ACCOUNT_LABEL.format(app_name=self.app_name)
+        account_text = LINK_STYLE.format(link_url='#', link_text=link_text)
+        self.ui.create_account_label.setText(account_text)
         self.ui.sign_in_button.setText(SIGN_IN_BUTTON)
 
     def _connect_ui(self):
         """Connect the buttons to perform actions."""
         self.ui.forgot_password_label.linkActivated.connect(
                                                     self.on_forgotten_password)
+        self.ui.create_account_label.linkActivated.connect(
+                                                    self.on_create_account)
         self.ui.email_edit.textChanged.connect(self._validate)
         self.ui.password_edit.textChanged.connect(self._validate)
         self.ui.sign_in_button.clicked.connect(self.login)
 
     def _validate(self):
         """Perform input validation."""
-        correct_mail = is_correct_email(unicode(self.ui.email_edit.text()))
-        correct_password = len(unicode(self.ui.password_edit.text())) > 0
+        correct_mail = is_correct_email(
+                        compat.text_type(self.ui.email_edit.text()))
+        correct_password = len(
+                        compat.text_type(self.ui.password_edit.text())) > 0
         enabled = correct_mail and correct_password
         self.ui.sign_in_button.setEnabled(enabled)
 
     def login(self):
         """Perform the login using the self.backend."""
         # grab the data from the view and call the backend
-        email = unicode(self.ui.email_edit.text())
+        email = compat.text_type(self.ui.email_edit.text())
         logger.info('CurrentUserSignInPage.login for: %s', email)
-        password = unicode(self.ui.password_edit.text())
+        password = compat.text_type(self.ui.password_edit.text())
         args = (self.app_name, email, password)
         if self.ping_url:
             f = self.backend.login_and_ping
@@ -163,7 +173,7 @@ class CurrentUserSignInPage(SSOWizardPage):
         """We managed to log in."""
         logger.info('Logged in for %s', app_name)
         self.hide_overlay()
-        email = unicode(self.ui.email_edit.text())
+        email = compat.text_type(self.ui.email_edit.text())
         logger.debug('About to emit userLoggedIn signal with: (%s).', email)
         self.userLoggedIn.emit(email)
 
@@ -172,3 +182,9 @@ class CurrentUserSignInPage(SSOWizardPage):
         self.hide_overlay()
         logger.debug('About to emit passwordForgotten signal')
         self.passwordForgotten.emit()
+
+    def on_create_account(self, link=None):
+        """Show the user the account creation page."""
+        self.hide_overlay()
+        logger.debug('About to emit createAccount signal')
+        self.createAccount.emit()
