@@ -28,9 +28,9 @@
 # files in the program, then also delete it here.
 """Customized Setup Account page for SSO."""
 
-import StringIO
 import tempfile
 import os
+from io import BytesIO
 from functools import partial
 
 # pylint: disable=F0401
@@ -53,6 +53,7 @@ from ubuntu_sso.qt import (
 )
 from ubuntu_sso.qt.sso_wizard_page import SSOWizardEnhancedEditPage
 from ubuntu_sso.qt.ui.setup_account_ui import Ui_SetUpAccountPage
+from ubuntu_sso.utils import compat
 from ubuntu_sso.utils.ui import (
     AGREE_TO_PRIVACY_POLICY,
     AGREE_TO_TERMS,
@@ -85,6 +86,7 @@ from ubuntu_sso.utils.ui import (
     RETYPE_EMAIL,
     RETYPE_PASSWORD,
     SET_UP_ACCOUNT_BUTTON,
+    SIGN_IN_LABEL,
     TERMS_TEXT,
     REGISTER_TITLE,
 )
@@ -99,7 +101,8 @@ class SetupAccountPage(SSOWizardEnhancedEditPage):
     """Customized Setup Account page for SSO."""
 
     ui_class = Ui_SetUpAccountPage
-    userRegistered = QtCore.pyqtSignal(unicode)
+    userRegistered = QtCore.pyqtSignal(compat.text_type)
+    signIn = QtCore.pyqtSignal()
 
     def __init__(self, *args, **kwargs):
         self.captcha_file = None
@@ -127,7 +130,7 @@ class SetupAccountPage(SSOWizardEnhancedEditPage):
     @property
     def password(self):
         """Return the content of the password edit."""
-        return unicode(self.ui.password_edit.text())
+        return compat.text_type(self.ui.password_edit.text())
 
     # Invalid name "initializePage"
     # pylint: disable=C0103
@@ -175,6 +178,9 @@ class SetupAccountPage(SSOWizardEnhancedEditPage):
         self.setSubTitle(self.help_text)
 
         self.ui.name_label.setText(NAME_ENTRY)
+        sign_in_link = LINK_STYLE.format(link_url='#',
+            link_text=SIGN_IN_LABEL)
+        self.ui.sign_in_label.setText(sign_in_link)
         self.ui.email_label.setText(EMAIL1_ENTRY)
         self.ui.confirm_email_label.setText(EMAIL2_ENTRY)
         self.ui.password_label.setText(PASSWORD1_ENTRY)
@@ -245,8 +251,8 @@ class SetupAccountPage(SSOWizardEnhancedEditPage):
                                                  common.NORMAL))
 
         self.ui.refresh_label.linkActivated.connect(self.hide_error)
-        self.ui.refresh_label.linkActivated.connect(lambda url: \
-                                          self._refresh_captcha())
+        self.ui.refresh_label.linkActivated.connect(
+            lambda url: self._refresh_captcha())
         # We need to check if we enable the button on many signals
         self.ui.name_edit.textEdited.connect(self._enable_setup_button)
         self.ui.email_edit.textEdited.connect(self._enable_setup_button)
@@ -258,17 +264,20 @@ class SetupAccountPage(SSOWizardEnhancedEditPage):
         self.ui.captcha_solution_edit.textEdited.connect(
             self._enable_setup_button)
         self.terms_checkbox.stateChanged.connect(self._enable_setup_button)
+        self.ui.sign_in_label.linkActivated.connect(self.signIn)
 
         self._refresh_captcha()
 
     def _enable_setup_button(self):
         """Only enable the setup button if the form is valid."""
-        name = unicode(self.ui.name_edit.text()).strip()
-        email = unicode(self.ui.email_edit.text())
-        confirm_email = unicode(self.ui.confirm_email_edit.text())
-        password = unicode(self.ui.password_edit.text())
-        confirm_password = unicode(self.ui.confirm_password_edit.text())
-        captcha_solution = unicode(self.ui.captcha_solution_edit.text())
+        name = compat.text_type(self.ui.name_edit.text()).strip()
+        email = compat.text_type(self.ui.email_edit.text())
+        confirm_email = compat.text_type(self.ui.confirm_email_edit.text())
+        password = compat.text_type(self.ui.password_edit.text())
+        confirm_password = compat.text_type(
+                self.ui.confirm_password_edit.text())
+        captcha_solution = compat.text_type(
+                self.ui.captcha_solution_edit.text())
 
         # Check for len(name) > 0 to ensure that a bool is assigned to enabled
         if not self.terms_checkbox.isVisible():
@@ -326,10 +335,10 @@ class SetupAccountPage(SSOWizardEnhancedEditPage):
         # done either by a setParent or something within the qtreactor, PIL
         # in this case does solve the issue. Sorry :(
         pil_image = Image.open(self.captcha_file)
-        string_io = StringIO.StringIO()
-        pil_image.save(string_io, format='png')
+        bytes_io = BytesIO()
+        pil_image.save(bytes_io, format='png')
         pixmap_image = QtGui.QPixmap()
-        pixmap_image.loadFromData(string_io.getvalue())
+        pixmap_image.loadFromData(bytes_io.getvalue())
         self.captcha_image = pixmap_image
         self.on_captcha_refresh_complete()
 
@@ -355,18 +364,20 @@ class SetupAccountPage(SSOWizardEnhancedEditPage):
     def on_user_registered(self, app_name, email):
         """Execute when the user did register."""
         self.hide_overlay()
-        email = unicode(self.ui.email_edit.text())
+        email = compat.text_type(self.ui.email_edit.text())
         self.userRegistered.emit(email)
 
     def validate_form(self):
         """Validate the info of the form and return an error."""
         logger.debug('SetUpAccountPage.validate_form')
-        name = unicode(self.ui.name_edit.text()).strip()
-        email = unicode(self.ui.email_edit.text())
-        confirm_email = unicode(self.ui.confirm_email_edit.text())
-        password = unicode(self.ui.password_edit.text())
-        confirm_password = unicode(self.ui.confirm_password_edit.text())
-        captcha_solution = unicode(self.ui.captcha_solution_edit.text())
+        name = compat.text_type(self.ui.name_edit.text()).strip()
+        email = compat.text_type(self.ui.email_edit.text())
+        confirm_email = compat.text_type(self.ui.confirm_email_edit.text())
+        password = compat.text_type(self.ui.password_edit.text())
+        confirm_password = compat.text_type(
+                self.ui.confirm_password_edit.text())
+        captcha_solution = compat.text_type(
+                self.ui.captcha_solution_edit.text())
         condition = True
         messages = []
         if not name:
@@ -395,11 +406,12 @@ class SetupAccountPage(SSOWizardEnhancedEditPage):
     def set_next_validation(self):
         """Set the validation as the next page."""
         logger.debug('SetUpAccountPage.set_next_validation')
-        email = unicode(self.ui.email_edit.text())
-        password = unicode(self.ui.password_edit.text())
-        name = unicode(self.ui.name_edit.text())
+        email = compat.text_type(self.ui.email_edit.text())
+        password = compat.text_type(self.ui.password_edit.text())
+        name = compat.text_type(self.ui.name_edit.text())
         captcha_id = self.captcha_id
-        captcha_solution = unicode(self.ui.captcha_solution_edit.text())
+        captcha_solution = compat.text_type(
+                self.ui.captcha_solution_edit.text())
         # validate the current info of the form, try to perform the action
         # to register the user, and then move foward
         if self.validate_form():
@@ -418,11 +430,11 @@ class SetupAccountPage(SSOWizardEnhancedEditPage):
 
     def is_correct_email_confirmation(self, email_address):
         """Return that the email is the same."""
-        return unicode(self.ui.email_edit.text()) == email_address
+        return compat.text_type(self.ui.email_edit.text()) == email_address
 
     def is_correct_password_confirmation(self, password):
         """Return that the passwords are correct."""
-        return unicode(self.ui.password_edit.text()) == password
+        return compat.text_type(self.ui.password_edit.text()) == password
 
     def focus_changed(self, old, now):
         """Check who has the focus to activate password popups if necessary."""
@@ -441,7 +453,7 @@ class SetupAccountPage(SSOWizardEnhancedEditPage):
 
     def name_assistance(self):
         """Show help for the name field."""
-        text = unicode(self.ui.name_edit.text())
+        text = compat.text_type(self.ui.name_edit.text())
         if not text.strip():
             self.set_error_message(self.ui.name_assistance,
                 EMPTY_NAME)
@@ -452,7 +464,7 @@ class SetupAccountPage(SSOWizardEnhancedEditPage):
 
     def email_assistance(self):
         """Show help for the email field."""
-        text = unicode(self.ui.email_edit.text())
+        text = compat.text_type(self.ui.email_edit.text())
         if not is_correct_email(text):
             self.set_error_message(self.ui.email_assistance,
                 INVALID_EMAIL)
@@ -463,8 +475,8 @@ class SetupAccountPage(SSOWizardEnhancedEditPage):
 
     def confirm_email_assistance(self):
         """Show help for the confirm email field."""
-        text1 = unicode(self.ui.email_edit.text())
-        text2 = unicode(self.ui.confirm_email_edit.text())
+        text1 = compat.text_type(self.ui.email_edit.text())
+        text2 = compat.text_type(self.ui.confirm_email_edit.text())
         if text1 != text2:
             self.set_error_message(self.ui.confirm_email_assistance,
                 EMAIL_MATCH)
