@@ -28,6 +28,8 @@
 # files in the program, then also delete it here.
 """Script that shows the qt gui."""
 
+from __future__ import unicode_literals
+
 import sys
 
 # pylint: disable=E1101,F0401,E0611
@@ -47,7 +49,6 @@ from ubuntu_sso.credentials import (
      PING_URL_KEY,
      POLICY_URL_KEY,
      TC_URL_KEY,
-     UI_EXECUTABLE_KEY,
 )
 
 
@@ -66,13 +67,12 @@ def main():
     client.cred_manager.connect_to_signal('AuthorizationDenied', found)
     client.cred_manager.connect_to_signal('CredentialsError', found)
 
-    yield client.cred_manager.login(u'Ubuntu Two',
+    yield client.cred_manager.login('Ubuntu Two',
         {
-            HELP_TEXT_KEY: u'This is a test help text.',
-            PING_URL_KEY: u'http://www.wikipedia.com/',
-            POLICY_URL_KEY: u'http://one.ubuntu.com/',
-            TC_URL_KEY: u'http://www.google.com/',
-            UI_EXECUTABLE_KEY: 'ubuntu-sso-login-gtk',
+            HELP_TEXT_KEY: 'This is a test help text.',
+            PING_URL_KEY: 'http://www.wikipedia.com/',
+            POLICY_URL_KEY: 'http://one.ubuntu.com/',
+            TC_URL_KEY: 'http://www.google.com/',
         })
     yield d
 
