@@ -28,8 +28,11 @@
 # files in the program, then also delete it here.
 """Tests for the Setup Account page Qt UI."""
 
+from __future__ import unicode_literals
+
 from PyQt4 import QtGui, QtCore
 
+from ubuntu_sso.utils import compat
 from ubuntu_sso.qt import current_user_sign_in_page as gui
 from ubuntu_sso.qt.tests import (
     PageBaseTestCase,
@@ -45,7 +48,8 @@ class CurrentUserSignInTestCase(PageBaseTestCase):
     """Test the SetupAccountPage code."""
 
     ui_class = gui.CurrentUserSignInPage
-    ui_signals = ('userLoggedIn', 'passwordForgotten', 'userNotValidated')
+    ui_signals = ('userLoggedIn', 'passwordForgotten', 'userNotValidated',
+        'createAccount')
     ui_backend_signals = ('LoggedIn', 'LoginError', 'UserNotValidated')
 
     def test_initialize_page(self):
@@ -66,30 +70,40 @@ class CurrentUserSignInTestCase(PageBaseTestCase):
 
     def test_unicode_in_forgotten_password_link(self):
         """Ensure that this label supports unicode."""
-        forgot_fr = u"J'ai oublié mon mot de passe"
+        forgot_fr = "J'ai oublié mon mot de passe"
         self.patch(gui, "FORGOTTEN_PASSWORD_BUTTON", forgot_fr)
         forgotten_text = gui.LINK_STYLE.format(link_url='#',
                             link_text=forgot_fr)
         self.ui._set_translated_strings()
-        self.assertEqual(unicode(self.ui.ui.forgot_password_label.text()),
-            forgotten_text)
+        self.assertEqual(
+                compat.text_type(self.ui.ui.forgot_password_label.text()),
+                forgotten_text)
 
     def test_set_translated_strings(self):
         """Test the translated string method."""
         expected = gui.LOGIN_TITLE.format(app_name=self.app_name)
+        self.assertTrue(self.app_name in expected)
         self.assert_title_correct(expected)
         expected = gui.LOGIN_SUBTITLE % dict(app_name=self.app_name)
+        self.assertTrue(self.app_name in expected)
         self.assert_subtitle_correct(expected)
-        self.assertEqual(unicode(self.ui.ui.email_label.text()),
+        self.assertEqual(compat.text_type(self.ui.ui.email_label.text()),
             gui.EMAIL_LABEL)
-        self.assertEqual(unicode(self.ui.ui.password_label.text()),
+        link_text = gui.CREATE_ACCOUNT_LABEL.format(app_name=self.app_name)
+        expected = gui.LINK_STYLE.format(link_url='#', link_text=link_text)
+        self.assertTrue(self.app_name in expected)
+        self.assertEqual(compat.text_type(
+            self.ui.ui.create_account_label.text()), expected)
+        self.assertEqual(compat.text_type(self.ui.ui.password_label.text()),
             gui.LOGIN_PASSWORD_LABEL)
         text = gui.LINK_STYLE.format(link_url='#',
                                      link_text=gui.FORGOTTEN_PASSWORD_BUTTON)
-        self.assertEqual(unicode(self.ui.ui.forgot_password_label.text()),
-            text)
-        self.assertEqual(unicode(self.ui.ui.sign_in_button.text()),
-            gui.SIGN_IN_BUTTON)
+        self.assertEqual(
+                compat.text_type(self.ui.ui.forgot_password_label.text()),
+                text)
+        self.assertEqual(
+                compat.text_type(self.ui.ui.sign_in_button.text()),
+                gui.SIGN_IN_BUTTON)
 
     def test_connect_ui(self):
         """Test the connect ui method."""
@@ -101,6 +115,8 @@ class CurrentUserSignInTestCase(PageBaseTestCase):
             QtCore.SIGNAL("textChanged(const QString&)")), 1)
         self.assertEqual(self.ui.ui.sign_in_button.receivers(
             QtCore.SIGNAL("clicked()")), 1)
+        self.assertEqual(self.ui.ui.create_account_label.receivers(
+            QtCore.SIGNAL("linkActivated(const QString&)")), 1)
 
     def test_validate_not_valid(self):
         """Test validate method."""
@@ -185,3 +201,13 @@ class CurrentUserSignInTestCase(PageBaseTestCase):
         """Forgotten passsword clicked emits passwordForgotten signal."""
         self.assert_signal_emitted(self.ui.passwordForgotten, (),
             self.ui.ui.forgot_password_label.linkActivated.emit, "link")
+
+    def test_on_create_account(self):
+        """Test the on_create_account method."""
+        self.assert_signal_emitted(self.ui.createAccount, (),
+            self.ui.on_create_account)
+
+    def test_on_create_account_link_clicked(self):
+        """Create account clicked emits createAccount signal."""
+        self.assert_signal_emitted(self.ui.createAccount, (),
+            self.ui.ui.create_account_label.linkActivated.emit, "link")
