@@ -30,6 +30,9 @@
 
 from PyQt4 import QtGui, QtCore
 
+from ubuntu_sso.utils import compat
+from ubuntu_sso.tests import CAPTCHA_PATH
+
 from ubuntu_sso.qt import common, setup_account_page as gui
 from ubuntu_sso.qt.tests import PageBaseTestCase
 
@@ -38,7 +41,7 @@ class SetupAccountTestCase(PageBaseTestCase):
     """Test the SetupAccountPage code."""
 
     ui_class = gui.SetupAccountPage
-    ui_signals = ('userRegistered',)
+    ui_signals = ('userRegistered', 'signIn')
     ui_backend_signals = ('CaptchaGenerated', 'CaptchaGenerationError',
                           'UserRegistered', 'UserRegistrationError')
 
@@ -67,7 +70,7 @@ class SetupAccountTestCase(PageBaseTestCase):
 
         self.ui.ui.refresh_label.linkActivated.emit('error')
 
-        message = unicode(self.ui.form_errors_label.text())
+        message = compat.text_type(self.ui.form_errors_label.text())
         self.assertEqual(message, ' ')
 
     def test_enable_setup_button_with_visible_check(self):
@@ -116,15 +119,15 @@ class SetupAccountTestCase(PageBaseTestCase):
         self.ui.focus_changed(None, self.ui.ui.password_edit)
         self.assertIn(
             common.NORMAL % common.PASSWORD_LENGTH,
-            unicode(self.ui.ui.password_assistance.text()),
+            compat.text_type(self.ui.ui.password_assistance.text()),
         )
         self.assertIn(
             common.NORMAL % common.PASSWORD_UPPER,
-            unicode(self.ui.ui.password_assistance.text()),
+            compat.text_type(self.ui.ui.password_assistance.text()),
         )
         self.assertIn(
             common.NORMAL % common.PASSWORD_DIGIT,
-            unicode(self.ui.ui.password_assistance.text()),
+            compat.text_type(self.ui.ui.password_assistance.text()),
         )
 
     def test_password_focus_gain(self):
@@ -219,16 +222,27 @@ class SetupAccountTestCase(PageBaseTestCase):
         self.assertFalse(self.ui.captcha_received)
 
         # labels
-        self.assertEqual(unicode(self.ui.ui.name_label.text()),
+        self.assertEqual(compat.text_type(self.ui.ui.name_label.text()),
             gui.NAME_ENTRY)
-        self.assertEqual(unicode(self.ui.ui.email_label.text()),
+        self.assertEqual(compat.text_type(self.ui.ui.email_label.text()),
             gui.EMAIL)
-        self.assertEqual(unicode(self.ui.ui.confirm_email_label.text()),
-                         gui.RETYPE_EMAIL)
-        self.assertEqual(unicode(self.ui.ui.password_label.text()),
+        self.assertEqual(
+                compat.text_type(self.ui.ui.confirm_email_label.text()),
+                gui.RETYPE_EMAIL)
+        self.assertEqual(compat.text_type(self.ui.ui.password_label.text()),
             gui.PASSWORD)
-        self.assertEqual(unicode(self.ui.ui.confirm_password_label.text()),
-                         gui.RETYPE_PASSWORD)
+        self.assertEqual(
+                compat.text_type(self.ui.ui.confirm_password_label.text()),
+                gui.RETYPE_PASSWORD)
+        expected = gui.LINK_STYLE.format(link_url='#',
+            link_text=gui.SIGN_IN_LABEL)
+        self.assertEqual(
+                compat.text_type(self.ui.ui.sign_in_label.text()),
+                expected)
+
+        # connections
+        self.assertEqual(self.ui.set_up_button.receivers(
+            QtCore.SIGNAL("clicked(const bool)")), 1)
 
         # assistants
         self.assertFalse(self.ui.ui.name_assistance.isVisible())
@@ -237,6 +251,36 @@ class SetupAccountTestCase(PageBaseTestCase):
         self.assertFalse(self.ui.ui.password_assistance.isVisible())
         self.assertTrue(self.ui.ui.refresh_label.isVisible())
 
+    def test_connect_ui(self):
+        """Test the connect ui method."""
+        self.assertEqual(self.ui.ui.password_edit.receivers(
+            QtCore.SIGNAL("textEdited(const QString&)")), 2)
+        self.assertEqual(self.ui.ui.refresh_label.receivers(
+            QtCore.SIGNAL("linkActivated(const QString&)")), 2)
+        self.assertEqual(self.ui.ui.name_edit.receivers(
+            QtCore.SIGNAL("textEdited(const QString&)")), 1)
+        self.assertEqual(self.ui.ui.email_edit.receivers(
+            QtCore.SIGNAL("textEdited(const QString&)")), 1)
+        self.assertEqual(self.ui.ui.confirm_email_edit.receivers(
+            QtCore.SIGNAL("textEdited(const QString&)")), 1)
+        self.assertEqual(self.ui.ui.password_edit.receivers(
+            QtCore.SIGNAL("textEdited(const QString&)")), 2)
+        self.assertEqual(self.ui.ui.confirm_password_edit.receivers(
+            QtCore.SIGNAL("textEdited(const QString&)")), 1)
+        self.assertEqual(self.ui.ui.sign_in_label.receivers(
+            QtCore.SIGNAL("linkActivated(const QString&)")), 1)
+
+    def test_connect_ui_2(self):
+        """Test more connections from connect_ui"""
+
+        #
+        self.assertEqual(self.ui.ui.captcha_solution_edit.receivers(
+            QtCore.SIGNAL("textEdited(const QString&)")), 1)
+        self.assertEqual(self.ui.terms_checkbox.receivers(
+            QtCore.SIGNAL("stateChanged(bool)")), 1)
+
+    test_connect_ui_2.skip = "These oscilate 0/1 (LP:1046885)"
+
     def test_set_up_button_clicked(self):
         """Validation and overlay is shown when the setupbutton is clicked."""
         self.patch(self.ui, 'set_next_validation', self._set_called)
@@ -337,6 +381,15 @@ class SetupAccountTestCase(PageBaseTestCase):
         self.ui.showEvent(QtGui.QShowEvent())
         self.ui.hideEvent(QtGui.QHideEvent())
 
+    def test_on_captcha_generated(self):
+        """Check that the captcha image is handled correctly."""
+
+        self.ui.captcha_file = CAPTCHA_PATH
+        self.ui.on_captcha_generated(u"fake app name",
+                                     "fake id")
+        pixmap_empty = self.ui.captcha_image.size().isEmpty()
+        self.assertEqual(pixmap_empty, False)
+
     def test_on_captcha_refreshing_visible(self):
         """Check the state of the overlay on captcha refreshing."""
         self.ui.hide_overlay()
