@@ -28,6 +28,8 @@
 # files in the program, then also delete it here.
 """Tests for the Ubuntu SSO library."""
 
+from __future__ import unicode_literals
+
 import os
 
 from collections import defaultdict
@@ -38,30 +40,30 @@ from twisted.trial import unittest
 
 from ubuntu_sso.keyring import get_token_name
 
-APP_NAME = u'I ♥ Ubuntu'
-CAPTCHA_ID = u'test ñiña'
+APP_NAME = 'I ♥ Ubuntu'
+CAPTCHA_ID = 'test ñiña'
 CAPTCHA_PATH = os.path.abspath(os.path.join(os.curdir, 'ubuntu_sso', 'tests',
                                             'files', 'captcha.png'))
-CAPTCHA_SOLUTION = u'william Byrd ñandú'
-EMAIL = u'test@example.com'
-EMAIL_TOKEN = u'B2P☺ gtf'
-GTK_GUI_EXE = 'ubuntu-sso-login-gtk'
-HELP_TEXT = u'☛ Lorem ipsum dolor sit amet, consectetur adipiscing elit. ' \
+CAPTCHA_SOLUTION = 'william Byrd ñandú'
+EMAIL = 'test@example.com'
+EMAIL_TOKEN = 'B2P☺ gtf'
+GUI_EXE = 'ubuntu-sso-login-qt'
+HELP_TEXT = '☛ Lorem ipsum dolor sit amet, consectetur adipiscing elit. ' \
 'Nam sed lorem nibh. Suspendisse gravida nulla non nunc suscipit pulvinar ' \
 'tempus ut augue. Morbi consequat, ligula a elementum pretium, ' \
 'dolor nulla tempus metus, sed viverra nisi risus non velit.'
-NAME = u'Juanito ☀ Pérez'
-PASSWORD = u'h3lloWorld☑ '
-PING_URL = u'http://localhost/ping-me/'
-POLICY_URL = u'http://localhost/policy/'
-RESET_PASSWORD_TOKEN = u'8G5Wtq'
-TOKEN = {u'consumer_key': u'xQ7xDAz',
-         u'consumer_secret': u'KzCJWCTNbbntwfyCKKjomJDzlgqxLy',
-         u'token_name': u'test',
-         u'token': u'GkInOfSMGwTXAUoVQwLUoPxElEEUdhsLVNTPhxHJDUIeHCPNEo',
-         u'token_secret': u'qFYImEtlczPbsCnYyuwLoPDlPEnvNcIktZphPQklAWrvyfFMV'}
+NAME = 'Juanito ☀ Pérez'
+PASSWORD = 'h3lloWorld☑ '
+PING_URL = 'http://localhost/ping-me/'
+POLICY_URL = 'http://localhost/policy/'
+RESET_PASSWORD_TOKEN = '8G5Wtq'
+TOKEN = {'consumer_key': 'xQ7xDAz',
+         'consumer_secret': 'KzCJWCTNbbntwfyCKKjomJDzlgqxLy',
+         'token_name': 'test',
+         'token': 'GkInOfSMGwTXAUoVQwLUoPxElEEUdhsLVNTPhxHJDUIeHCPNEo',
+         'token_secret': 'qFYImEtlczPbsCnYyuwLoPDlPEnvNcIktZphPQklAWrvyfFMV'}
 TOKEN_NAME = get_token_name(APP_NAME)
-TC_URL = u'http://localhost/'
+TC_URL = 'http://localhost/'
 WINDOW_ID = 5
 
 
