@@ -36,8 +36,20 @@ from ubuntu_sso.utils.ui import (get_password_strength,
                                  is_correct_email)
 
 
+class GettextTestCase(TestCase):
+    """Test that we don't override builtins with gettext."""
+
+    def test_import(self):
+        """Test whether importing ui module defines _ as a builtin."""
+        # This module is already imported above, but just to make sure, since
+        # top imports may change over time.
+        import ubuntu_sso.utils.ui  # pylint: disable=W0612
+        with self.assertRaises(NameError):
+            _  # pylint: disable=W0104,E0602
+
+
 class GetPasswordStrengTestCase(TestCase):
-    """Test the function that returns the strengh of a password."""
+    """Test the function that returns the strength of a password."""
 
     def test_too_small_password(self):
         """Test the points given to a very small password."""
