@@ -31,11 +31,16 @@
 import argparse
 import re
 import gettext
+import sys
 
 from ubuntu_sso.logger import setup_logging
 
+TRANSLATION = gettext.translation('ubuntu-sso-client', fallback=True)
+if sys.version_info < (3,):
+    _ = TRANSLATION.ugettext
+else:
+    _ = TRANSLATION.gettext
 
-gettext.install('ubuntu-sso-client', unicode=True)
 logger = setup_logging('ubuntu_sso.utils.ui')
 
 
@@ -60,6 +65,7 @@ CLOSE_AND_SETUP_LATER = _('Close window and set up later')
 CONGRATULATIONS = _("Congratulations, {app_name} is installed!")
 CONNECT_HELP_LABEL = _('To connect this computer to %(app_name)s enter your '
     'details below.')
+CREATE_ACCOUNT_LABEL = _('Register with {app_name}.')
 EMAIL_LABEL = EMAIL1_ENTRY = _('Email address')
 EMAIL2_ENTRY = _('Re-type Email address')
 EMAIL_INVALID = _('The email must be a valid email address.')
@@ -142,6 +148,7 @@ SET_NEW_PASSWORD_LABEL = _('A password reset code has been sent to '
 SET_UP_ACCOUNT_BUTTON = _('Set Up Account')
 SET_UP_ACCOUNT_CHOICE_BUTTON = _('I don\'t have an account yet - sign me up')
 SIGN_IN_BUTTON = _('Sign In')
+SIGN_IN_LABEL = _('Log-in with my existing account.')
 SSL_APPNAME_HELP = _('the appname whose ssl error we are going to show.')
 SSL_CERT_DETAILS = _('Certificate details')
 SSL_CONNECT_BUTTON = _('Connect')
