@@ -28,20 +28,33 @@
 # files in the program, then also delete it here.
 """Integration tests for the proxy-enabled webclient."""
 
+import logging
 import os
 import shutil
 import sys
-import urllib
+
+try:
+    # pylint: disable=E0611,F0401
+    from urllib.parse import (urlencode, unquote, urlparse,
+                              urljoin, parse_qsl)
+    # pylint: enable=E0611,F0401
+except ImportError:
+    from urllib import urlencode, unquote
+    from urlparse import urlparse, urljoin, parse_qsl
 
 from OpenSSL import crypto
 from socket import gethostname
 from twisted.cred import checkers, portal
 from twisted.internet import defer
 from twisted.web import guard, http, resource
-from urllib2 import urlparse
-
+from ubuntuone.devtools.handlers import MementoHandler
 from ubuntuone.devtools.testcases import TestCase
 from ubuntuone.devtools.testcases.squid import SquidTestCase
+from ubuntuone.devtools.testing.txwebserver import (
+    HTTPWebServer,
+    HTTPSWebServer,
+)
+
 
 from ubuntu_sso import (
     keyring,
@@ -53,7 +66,6 @@ from ubuntu_sso.utils import webclient
 from ubuntu_sso.utils.ui import SSL_DETAILS_TEMPLATE
 from ubuntu_sso.utils.webclient import gsettings, txweb
 from ubuntu_sso.utils.webclient.common import BaseWebClient, HeaderDict, oauth
-from ubuntu_sso.utils.webclient.tests import BaseMockWebServer
 
 ANY_VALUE = object()
 SAMPLE_KEY = "result"
@@ -182,34 +194,49 @@ class OAuthCheckerResource(resource.Resource):
         return "ERROR: Expected OAuth header not present."
 
 
-class MockWebServer(BaseMockWebServer):
+def get_root_resource():
+    """Get the root resource with all the children."""
+    root = resource.Resource()
+    root.putChild(SIMPLERESOURCE, SimpleResource())
+    root.putChild(BYTEZERORESOURCE, ByteZeroResource())
+    root.putChild(POSTABLERESOURCE, PostableResource())
+
+    root.putChild(THROWERROR, resource.NoResource())
+
+    unauthorized_resource = resource.ErrorPage(resource.http.UNAUTHORIZED,
+                                                "Unauthorized", "Unauthorized")
+    root.putChild(UNAUTHORIZED, unauthorized_resource)
+    root.putChild(HEADONLY, HeadOnlyResource())
+    root.putChild(VERIFYHEADERS, VerifyHeadersResource())
+    root.putChild(VERIFYPOSTPARAMS, VerifyPostParameters())
+    root.putChild(OAUTHRESOURCE, OAuthCheckerResource())
+
+    db = checkers.InMemoryUsernamePasswordDatabaseDontUse()
+    db.addUser(SAMPLE_USERNAME, SAMPLE_PASSWORD)
+    test_portal = portal.Portal(SimpleRealm(), [db])
+    cred_factory = guard.BasicCredentialFactory("example.org")
+    guarded_resource = guard.HTTPAuthSessionWrapper(test_portal,
+                                                        [cred_factory])
+    root.putChild(GUARDED, guarded_resource)
+    return root
+
+
+class HTTPMockWebServer(HTTPWebServer):
     """A mock webserver for the webclient tests."""
 
-    def get_root_resource(self):
-        """Get the root resource with all the children."""
-        root = resource.Resource()
-        root.putChild(SIMPLERESOURCE, SimpleResource())
-        root.putChild(BYTEZERORESOURCE, ByteZeroResource())
-        root.putChild(POSTABLERESOURCE, PostableResource())
+    def __init__(self):
+        """Create a new instance."""
+        root = get_root_resource()
+        super(HTTPMockWebServer, self).__init__(root)
 
-        root.putChild(THROWERROR, resource.NoResource())
 
-        unauthorized_resource = resource.ErrorPage(resource.http.UNAUTHORIZED,
-                                                "Unauthorized", "Unauthorized")
-        root.putChild(UNAUTHORIZED, unauthorized_resource)
-        root.putChild(HEADONLY, HeadOnlyResource())
-        root.putChild(VERIFYHEADERS, VerifyHeadersResource())
-        root.putChild(VERIFYPOSTPARAMS, VerifyPostParameters())
-        root.putChild(OAUTHRESOURCE, OAuthCheckerResource())
+class HTTPSMockWebServer(HTTPSWebServer):
+    """A mock webserver for the webclient tests."""
 
-        db = checkers.InMemoryUsernamePasswordDatabaseDontUse()
-        db.addUser(SAMPLE_USERNAME, SAMPLE_PASSWORD)
-        test_portal = portal.Portal(SimpleRealm(), [db])
-        cred_factory = guard.BasicCredentialFactory("example.org")
-        guarded_resource = guard.HTTPAuthSessionWrapper(test_portal,
-                                                        [cred_factory])
-        root.putChild(GUARDED, guarded_resource)
-        return root
+    def __init__(self, ssl_settings):
+        """Create a new instance."""
+        root = get_root_resource()
+        super(HTTPSMockWebServer, self).__init__(root, ssl_settings)
 
 
 class FakeQApplication(object):
@@ -264,11 +291,12 @@ class WebClientTestCase(TestCase):
     @defer.inlineCallbacks
     def setUp(self):
         yield super(WebClientTestCase, self).setUp()
-        self.ws = MockWebServer()
-        self.addCleanup(self.ws.stop)
-        self.base_iri = self.ws.get_iri()
         self.wc = self.webclient_factory()
         self.addCleanup(self.wc.shutdown)
+        self.ws = HTTPMockWebServer()
+        self.ws.start()
+        self.addCleanup(self.ws.stop)
+        self.base_iri = self.ws.get_iri()
 
     @defer.inlineCallbacks
     def test_request_takes_an_iri(self):
@@ -304,7 +332,7 @@ class WebClientTestCase(TestCase):
     @defer.inlineCallbacks
     def test_post_with_args(self):
         """Test a post request with arguments."""
-        args = urllib.urlencode(SAMPLE_POST_PARAMS)
+        args = urlencode(SAMPLE_POST_PARAMS)
         iri = self.base_iri + VERIFYPOSTPARAMS + "?" + args
         headers = {
             "content-type": "application/x-www-form-urlencoded",
@@ -420,6 +448,52 @@ class TxWebClientTestCase(WebClientTestCase):
 
     webclient_factory = txweb.WebClient
 
+    @defer.inlineCallbacks
+    def setUp(self):
+        """Set the diff tests."""
+        # delay import, otherwise a default reactor gets installed
+        from twisted.web import client
+        self.factory = client.HTTPClientFactory
+        # set the factory to be used
+        # Hook the server's buildProtocol to make the protocol instance
+        # accessible to tests and ensure that the reactor is clean!
+        build_protocol = self.factory.buildProtocol
+        self.serverProtocol = None
+
+        def remember_protocol_instance(my_self, addr):
+            """Remember the protocol used in the test."""
+            protocol = build_protocol(my_self, addr)
+            self.serverProtocol = protocol
+            on_connection_lost = defer.Deferred()
+            connection_lost = protocol.connectionLost
+
+            def defer_connection_lost(protocol, *a):
+                """Lost connection."""
+                if not on_connection_lost.called:
+                    on_connection_lost.callback(None)
+                connection_lost(protocol, *a)
+
+            self.patch(protocol, 'connectionLost', defer_connection_lost)
+
+            def cleanup():
+                """Clean the connection."""
+                if self.serverProtocol.transport is not None:
+                    self.serverProtocol.transport.loseConnection()
+                return on_connection_lost
+
+            self.addCleanup(cleanup)
+            return protocol
+
+        self.factory.buildProtocol = remember_protocol_instance
+        self.addCleanup(self.set_build_protocol, build_protocol)
+        txweb.WebClient.client_factory = self.factory
+
+        yield super(TxWebClientTestCase, self).setUp()
+
+    def set_build_protocol(self, method):
+        """Set the method back."""
+        self.factory.buildProtocol = method
+
 
 class TxWebClientReactorReplaceableTestCase(TestCase):
     """In the txweb client the reactor is replaceable."""
@@ -478,7 +552,8 @@ class BasicProxyTestCase(SquidTestCase):
     @defer.inlineCallbacks
     def setUp(self):
         yield super(BasicProxyTestCase, self).setUp()
-        self.ws = MockWebServer()
+        self.ws = HTTPMockWebServer()
+        self.ws.start()
         self.addCleanup(self.ws.stop)
         self.base_iri = self.ws.get_iri()
         self.wc = webclient.webclient_factory()
@@ -674,7 +749,7 @@ class OAuthPlainTextTestCase(TestCase):
         method, params_string = header.split(" ", 1)
         for p in params_string.split(","):
             k, v = p.strip().split("=")
-            params[k] = urllib.unquote(v[1:-1])
+            params[k] = unquote(v[1:-1])
 
         return method, params
 
@@ -684,15 +759,24 @@ class OAuthPlainTextTestCase(TestCase):
 
         self.assertEqual(method, "OAuth")
 
-        for k, expected_value in self.expected_params.iteritems():
+        for k, expected_value in self.expected_params.items():
             self.assertIn(k, params)
             if expected_value is not ANY_VALUE:
                 self.assertEqual(params[k], expected_value)
 
+    @defer.inlineCallbacks
     def test_build_oauth_headers(self):
         """Check that the oauth headers are properly built."""
-        headers = self.wc.build_oauth_headers(self.sample_method,
-                        self.sample_url, SAMPLE_CREDENTIALS, self.timestamp)
+
+        def get_timestamp():
+            """Return the timestamp."""
+            return defer.succeed(self.timestamp)
+
+        self.patch(self.wc, 'get_timestamp', get_timestamp)
+
+        headers = yield self.wc.build_request_headers(self.sample_url,
+                                         method=self.sample_method,
+                                         oauth_credentials=SAMPLE_CREDENTIALS)
         self.assert_headers_correct(headers)
 
     def test_build_oauth_request(self, params=None):
@@ -704,7 +788,7 @@ class OAuthPlainTextTestCase(TestCase):
         self.assert_headers_correct(request.to_header())
         self.assertEqual(request.http_url, self.sample_url)
         if params is not None:
-            for param, value in params.iteritems():
+            for param, value in params.items():
                 self.assertIn(param, request.parameters)
                 actual = request.parameters[param]
                 self.assertEqual(value, actual)
@@ -726,12 +810,12 @@ class OAuthPlainTextTestCase(TestCase):
         result = yield self.wc.build_signed_iri(iri, SAMPLE_CREDENTIALS,
                                           parameters=params)
 
-        scheme, netloc, path, params, query, _ = urlparse.urlparse(result)
+        scheme, netloc, path, params, query, _ = urlparse(result)
 
-        self.assertEqual(urlparse.urljoin(scheme + '://' + netloc, path), uri)
+        self.assertEqual(urljoin(scheme + '://' + netloc, path), uri)
 
         expected = request.parameters
-        actual = dict(urlparse.parse_qsl(query))
+        actual = dict(parse_qsl(query))
         for i in ('oauth_nonce', 'oauth_signature'):
             expected.pop(i)
             actual.pop(i)
@@ -882,10 +966,10 @@ class BaseSSLTestCase(SquidTestCase):
                                                              self.cert_details)
         self.addCleanup(self._clean_ssl_certificate_files)
 
-        self.ws = MockWebServer(self.ssl_settings)
+        self.ws = HTTPSMockWebServer(self.ssl_settings)
+        self.ws.start()
         self.addCleanup(self.ws.stop)
         self.base_iri = self.ws.get_iri()
-        self.base_ssl_iri = self.ws.get_ssl_iri()
 
     def _clean_ssl_certificate_files(self):
         """Remove the certificate files."""
@@ -986,7 +1070,7 @@ class CorrectProxyTestCase(BaseSSLTestCase):
         """
         # we fail due to the fake ssl cert
         yield self.failUnlessFailure(self.wc.request(
-                                     self.base_ssl_iri + SIMPLERESOURCE),
+                                     self.base_iri + SIMPLERESOURCE),
                                      webclient.WebClientError)
         # https requests do not use the auth proxy therefore called should be
         # empty. This asserts that we are using the correct settings for the
@@ -1034,6 +1118,12 @@ class SSLTestCase(BaseSSLTestCase):
         """Set the diff tests."""
         yield super(SSLTestCase, self).setUp()
 
+        self.memento = MementoHandler()
+        self.memento.setLevel(logging.DEBUG)
+        logger = webclient.webclient_module().logger
+        logger.addHandler(self.memento)
+        self.addCleanup(logger.removeHandler, self.memento)
+
         self.wc = webclient.webclient_factory()
         self.addCleanup(self.wc.shutdown)
 
@@ -1053,7 +1143,7 @@ class SSLTestCase(BaseSSLTestCase):
         self.return_code = USER_SUCCESS
         if proxy_settings:
             self.wc.force_use_proxy(proxy_settings)
-        yield self.wc.request(self.base_ssl_iri + SIMPLERESOURCE)
+        yield self.wc.request(self.base_iri + SIMPLERESOURCE)
         details = SSL_DETAILS_TEMPLATE % self.cert_details
         self.assertIn(('_launch_ssl_dialog', gethostname(), details),
                       self.called)
@@ -1066,10 +1156,12 @@ class SSLTestCase(BaseSSLTestCase):
         """Test showing the dialog and accepting when using a proxy."""
         self._assert_ssl_fail_user_accepts(self.get_nonauth_proxy_settings())
 
-    def test_ssl_fail_dialog_user_rejects(self):
+    def test_ssl_fail(self):
         """Test showing the dialog and rejecting."""
-        self.failUnlessFailure(self.wc.request(self.base_iri + SIMPLERESOURCE),
+        self.failUnlessFailure(self.wc.request(
+                                     self.base_iri + SIMPLERESOURCE),
                                      webclient.WebClientError)
+        self.assertNotEqual(None, self.memento.check_error('SSL errors'))
 
     def test_format_ssl_details(self):
         """Assert that details are correctly formatted"""
@@ -1082,4 +1174,4 @@ class SSLTestCase(BaseSSLTestCase):
         reason = 'SSL support has not yet been implemented.'
         test_ssl_fail_dialog_user_accepts.skip = reason
         test_ssl_fail_dialog_user_accepts_via_proxy.skip = reason
-        test_ssl_fail_dialog_user_rejects.skip = reason
+        test_ssl_fail.skip = reason
